import { SlashCommandBuilder, ChatInputCommandInteraction, PermissionsBitField } from "npm:discord.js";
import { connectToDb, getGuild, setAdminRole, addGuild } from "../../libs/mysql.ts"
import { errorEmbed, successEmbed } from "../../libs/discord.ts";


export default {
	data: new SlashCommandBuilder()
		.setName("setadminrole")
		.setDescription("Set the admin role for the bot")
        .addRoleOption(option => option.setName("role").setDescription("The role to be admin.").setRequired(true)),
	async execute(interaction: ChatInputCommandInteraction) {
		const guild_id: string = interaction.guildId ? interaction.guildId : "";
        const member = interaction.guild?.members.cache.get(interaction.user.id);

        if (!member?.permissions.has(PermissionsBitField.Flags.ManageGuild)) {
            const embed = errorEmbed("You are not allowed to use that command.", interaction.client.user.displayAvatarURL());

            return await interaction.reply({embeds: [embed]});
        }

        const connection = await connectToDb();

        const guild: any[] = await getGuild(connection, guild_id);

        if (!guild[0]) {
            await addGuild(connection, guild_id);
        }

        const role_id: string | undefined = interaction.options.getRole("role")?.id

        await setAdminRole(connection, guild_id, role_id ? role_id : "");

        connection.end()

        const embed = successEmbed("The bot admin role has been successfully changed.", interaction.client.user.displayAvatarURL())

        interaction.reply({embeds: [embed]})
	},
};
